@@ -11,7 +11,7 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.33_01';
+$VERSION = '0.33_02';
 
 %EXPORT_TAGS = (
     'all' => [qw(
@@ -54,14 +54,18 @@ sub import {
             splice @_, $i, 1;
             next;
         }
-        # :snap=N
-        if (length($v) > 5 and substr($v,0,5) eq ':snap') {
-            my $arg = substr $v, 5;
-            if (length($arg) < 2 or substr($arg, 0, 1) ne '=') {
-                croak "Usage: :snap=N";
+        # :defer[=N]
+        if (length($v) >= 6 and substr($v,0,6) eq ':defer') {
+            my $arg = substr $v, 6;
+            my $len = length $arg;
+            if ($len == 0) {
+                $arg = '=0.001';
+            }
+            elsif ($len == 1 or substr($arg, 0, 1) ne '=') {
+                croak "Usage: :defer[=N]";
             }
             my $val = substr $arg, 1;
-            _snap($val);
+            _defer($val);
             splice @_, $i, 1;
             next;
         }
@@ -345,8 +349,8 @@ Same as B<uuid1()> but version 7.
 
 Returns the variant of binary I<$uuid>.
 
-This module only generates variant 1 UUIDs, but others may be found in
-the wild.
+This module only generates variant 1 UUIDs. Others may be found in the
+wild.
 
 Known variants:
 
@@ -359,10 +363,11 @@ Known variants:
 
 Returns the version of binary I<$uuid>.
 
-This module only generates version 1, 4, 6, and version 7 UUIDs, but
-others may be found in the wild.
+This module only generates version 1, 3, 4, 5, 6, and version 7 UUIDs.
+Others may be found in the wild.
 
 Known versions:
+
     v1  date/time and node address
     v2  date/time and node address, security version
     v3  namespace based, MD5 hash
@@ -398,11 +403,13 @@ non-issue.
 
 =head1 RANDOM NUMBERS
 
+Versions 4 and 7 UUIDs are partially filled with random numbers, as well
+as versions 1 and 6 when used with the B<:mac> option.
+
 Prior to version 0.33, UUID obtained randomness from the system's
 I</dev/random> device, or similar interface. On some platforms it called
 B<getrandom()> and on others it read directly from I</dev/urandom>. And
-of course, Win32 did something completely different depending on the
-environment.
+of course, Win32 did something completely different.
 
 Starting in 0.33, UUID generates random numbers itself using the
 ChaCha20 algorithm which is considered crypto-strength in most circles.
@@ -457,6 +464,18 @@ B<WARNING>: Do not B<:persist> in a public directory. See CVE-2013-4184.
 UUID attempts to avoid this, but nothing is foolproof. Only YOU can
 prevent symlink attacks!
 
+=head2 B<:defer>[=I<N>]
+
+Persistence of state is deferred I<N> seconds when generating time-based
+UUIDs. More precisely, state is only saved every I<N> seconds. If UUIDs
+are generated more often, those within the I<N> second window will not
+save state.
+
+Defer values greater than some platform-specific interval greatly reduce
+the performance penalty introduced through persistence. While the
+default, B<:defer=0.001>, is probably fine, you can run B<make persist>
+in the distribution directory to see the effect of various values.
+
 =head1 THREAD SAFETY
 
 This module is believed to be thread safe.
